@@ -1,8 +1,6 @@
-from grow.common import markdown_extensions
 from grow.common import utils
 from grow.pods import urls
 from grow.pods.collectionz import messages
-import jinja2
 import json
 import logging
 import markdown
@@ -35,7 +33,7 @@ class Document(object):
 
   def __init__(self, pod_path, _pod, locale=None, _collection=None, body_format=None):
     utils.validate_name(pod_path)
-    self.locale = locale or _pod.podspec.default_locale
+    self.locale = locale
     self.pod_path = pod_path
     self.basename = os.path.basename(pod_path)
     self._slug_clean, self.ext = os.path.splitext(self.basename)
@@ -60,12 +58,6 @@ class Document(object):
       return "<Document({}, locale='{}')>".format(self.pod_path, self.locale)
     return "<Document({})>".format(self.pod_path)
 
-  def __cmp__(self, other):
-    return self.pod_path == other.pod_path and self.pod == other.pod
-
-  def __ne__(self, other):
-    return self.pod_path != other.pod_path or self.pod != other.pod
-
   @property
   def url(self):
     path = self.get_serving_path()
@@ -73,8 +65,6 @@ class Document(object):
 
   @property
   def slug(self):
-    if '$slug' in self.fields:
-      return self.fields['$slug']
     if self.parent:
       return '/{}/{}/'.format(self.parent.slug, self._slug_clean)
     return self._slug_clean
@@ -91,11 +81,6 @@ class Document(object):
   def title(self):
     return self.fields.get('$title')
 
-  def titles(self, title_name=None):
-    if title_name is None:
-      return self.title
-    return self.fields.get('$titles', {}).get(title_name, self.title)
-
   @property
   def published(self):
     return self.fields.get('$published')
@@ -124,7 +109,7 @@ class Document(object):
     if self.locale:
       if '$localization' in self.fields and self.fields['$localization']['path']:
         val = self.fields['$localization']['path']
-      elif self.collection.localization:
+      else:
         val = self.collection.localization['path']
     if val is None:
       return self.fields.get('$path', self.collection.get_path_format())
@@ -149,11 +134,9 @@ class Document(object):
         .replace('<grow:published_year>', '{published_year}'))
     try:
       return path_format.format(**{
-          'doc': self,
           'parent': self.parent if self.parent else DummyDict(),
           'locale': self.locale,
-          'podspec': self.pod.get_podspec(),
-          'base': os.path.splitext(os.path.basename(self.pod_path))[0],
+          'self': self,
           'slug': self.slug,
       }).replace('//', '/')
     except KeyError:
@@ -178,8 +161,9 @@ class Document(object):
     content = self.doc_storage.content
     return content.decode('utf-8')
 
-  def html(self, params=None):
-    return self.doc_storage.html(self, params)
+  @property
+  def html(self):
+    return self.doc_storage.html
 
   def __eq__(self, other):
     return (isinstance(self, Document)
@@ -189,12 +173,12 @@ class Document(object):
   def __getattr__(self, name):
     if name in self.fields:
       return self.fields[name]
+#    if '${}'.format(name) in self.yaml:
+#      return self.yaml['${}'.format(name)]
     return object.__getattribute__(self, name)
 
-  def next(self, docs=None):
-    # TODO(jeremydw): Verify items is a list of docs.
-    if docs is None:
-      docs = self.collection.search_docs()
+  def get_next(self):
+    docs = self.collection.list_servable_documents()
     for i, doc in enumerate(docs):
       if doc == self:
         n = i + 1
@@ -202,10 +186,8 @@ class Document(object):
           return None
         return docs[i + 1]
 
-  def prev(self, docs=None):
-    # TODO(jeremydw): Verify items is a list of docs.
-    if docs is None:
-      docs = self.collection.search_docs()
+  def get_prev(self):
+    docs = self.collection.list_servable_documents()
     for i, doc in enumerate(docs):
       if doc == self:
         n = i - 1
@@ -244,9 +226,25 @@ class Document(object):
     message.body = self.body
     message.content = self.content
     message.fields = json.dumps(self.fields, cls=utils.JsonEncoder)
+    message.html = self.doc_storage.html
     message.serving_path = self.get_serving_path()
     return message
 
+#    return
+#    if message.content is not None:
+#      self.pod.storage.write_file(self.pod_path, message.content)
+#    elif message.fields is not None and message.body is not None:
+#      fields = '{}'
+#      content = '---\n{}---\n{}'.format(fields, message.body)
+#      self.pod.storage.write_file(self.pod_path, content)
+#    elif message.fields is not None and message.body is None:
+#      fields = '{}'
+#      self.pod.storage.write_file(self.pod_path, content)
+#    elif message.fields is None and message.body is not None:
+#      self.pod.storage.write_file(self.pod_path, message.body)
+#    else:
+#      self.pod.storage.write_file(self.pod_path, '')
+
 
 class BaseDocumentStorage(object):
 
@@ -265,7 +263,8 @@ class BaseDocumentStorage(object):
   def load(self):
     raise NotImplementedError
 
-  def html(self, doc, params=None):
+  @property
+  def html(self):
     return self.body
 
   def write(self, content):
@@ -294,20 +293,25 @@ class MarkdownDocumentStorage(BaseDocumentStorage):
     self.fields = fields or {}
     self.body = body
 
-  def html(self, doc, params=None):
+  @property
+  def html(self):
     val = self.body
     if val is not None:
       extensions = [
         'toc',
-        'tables',
-        markdown_extensions.IncludeExtension(doc.pod),
-        markdown_extensions.UrlExtension(doc.pod),
       ]
       val = markdown.markdown(val.decode('utf-8'), extensions=extensions)
-      if params is None:
-        params = {}
-      if params:
-        params['doc'] = doc
-        template = jinja2.Template(val)
-        val = template.render(params)
     return val
+
+
+#class EmbeddedDocument(object):
+#
+#  def __init__(self, document):
+#    self.document = document
+#
+#  def __getattr__(self, name):
+#    if name in self.document.fields:
+#      return self.document.fields[name]
+##    if '${}'.format(name) in self.yaml:
+##      return self.yaml['${}'.format(name)]
+#    return self.document.__getattribute__(self.document, name)
